@@ -7,5 +7,5 @@ class LogMiddleWare:
 
     def __call__(self, request):
         response = self.get_response(request)
-        Inteliger().log(request=request, response=response)
+        Inteliger().salvar_log(request=request, response=response)
         return response
\ No newline at end of file
